Struct haproxy_api::Proxy [−][src]
The “Proxy” class provides a way for manipulating proxy and retrieving information like statistics.
Fields
name: Stringuuid: Stringstktable: Option<StickTable<'lua>>Implementations
impl<'lua> Proxy<'lua>[src]
pub fn pause(&self) -> Result<()>[src]
Pauses the proxy. See the management socket documentation for more information.
pub fn resume(&self) -> Result<()>[src]
Resumes the proxy. See the management socket documentation for more information.
pub fn stop(&self) -> Result<()>[src]
Stops the proxy. See the management socket documentation for more information.
pub fn shut_bcksess(&self) -> Result<()>[src]
Kills the session attached to a backup server. See the management socket documentation for more information.
pub fn get_cap(&self) -> Result<ProxyCapability>[src]
Returns a enum describing the capabilities of the proxy.
pub fn get_mode(&self) -> Result<ProxyMode>[src]
Returns a enum describing the mode of the current proxy.
pub fn get_stats(&self) -> Result<Table<'lua>>[src]
Returns a table containing the proxy statistics. The statistics returned are not the same if the proxy is frontend or a backend.
pub fn servers(&self) -> Result<HashMap<String, Server<'lua>>>[src]
Returns a map with the attached servers. The map is indexed by server name.